@@ -23,11 +23,13 @@ if hasattr(settings, 'CRONTAB_DJANGO_MANAGE_PATH'):
     if not os.path.exists(DJANGO_MANAGE_PATH):
         print 'ERROR: No manage.py file found at "%s". Check settings.CRONTAB_DJANGO_MANAGE_PATH!' % DJANGO_MANAGE_PATH
 else:
+    def ext(fpath):
+        return os.path.splitext(fpath)[0] + '.py'
     try:  # Django 1.3
-        DJANGO_MANAGE_PATH = import_module(DJANGO_PROJECT_NAME + '.manage').__file__.replace('pyc', 'py')
+        DJANGO_MANAGE_PATH = ext(import_module(DJANGO_PROJECT_NAME + '.manage').__file__)
     except ImportError:
-        try:  # Django 1.4
-            DJANGO_MANAGE_PATH = import_module('manage').__file__.replace('pyc', 'py')
+        try:  # Django 1.4+
+            DJANGO_MANAGE_PATH = ext(import_module('manage').__file__)
         except ImportError:
             print 'ERROR: Can\'t find your manage.py - please define settings.CRONTAB_DJANGO_MANAGE_PATH'
 
@@ -37,3 +39,5 @@ CRONTAB_COMMENT = getattr(settings, 'CRONTAB_COMMENT', 'django-cronjobs for %s'
 
 COMMAND_PREFIX = getattr(settings, 'CRONTAB_COMMAND_PREFIX', '')
 COMMAND_SUFFIX = getattr(settings, 'CRONTAB_COMMAND_SUFFIX', '')
+
+LOCK_JOBS = getattr(settings, 'CRONTAB_LOCK_JOBS', False)
